Map layers. Layers for the map view that can handle input, and draw on top of the map view different kinds of data.
Modules
- area
- Area layer A layer for placing polygons on the map.
- drawing
- Drawing layer A layer for freeform drawing on the map.
- geojson
- GeoJSON serialization and deserialization for layers. GeoJSON serialization and deserialization for layers.
- text
- Text layer A layer for placing text on the map.
- tile
- A layer for tile maps on the map.
Traits
- Layer
- A trait for map layers.