AreaShape

Enum AreaShape 

pub enum AreaShape {
    Polygon(Vec<GeoPos>),
    Circle {
        center: GeoPos,
        radius: f64,
        points: Option<i64>,
    },
    Ellipse {
        center: GeoPos,
        radius_major: f64,
        radius_minor: f64,
        rotation: f64,
        points: Option<i64>,
    },
}
The shape of a polygon area on the map.

Variants



Polygon(Vec<GeoPos>)

A freeform polygon defined by a list of points.



Circle

A circle defined by its center and radius in meters.

Fields

center: GeoPos

The geographical center of the circle.

radius: f64

The radius of the circle in meters.

points: Option<i64>

How many points should be used to draw the circle. If None the the point count is determined automatically which might look edged depending on zoom and projection.



Ellipse

An ellipse defined by its center, major and minor radii in meters, and rotation in radians.

Fields

center: GeoPos

The geographical center of the ellipse.

radius_major: f64

The semi-major axis (radius) of the ellipse in meters.

radius_minor: f64

The semi-minor axis (radius) of the ellipse in meters.

rotation: f64

The rotation of the ellipse in radians, measured counter-clockwise from the East (positive X-axis).

points: Option<i64>

How many points should be used to draw the ellipse. If None, the point count is determined automatically.