Module text

Module text 

Text layer A layer for placing text on the map.

Structs

EditingText
The state of the text currently being edited or added.
Text
A piece of text on the map.
TextLayer
Layer implementation that allows placing text on the map.

Enums

TextLayerMode
The mode of the TextLayer.
TextSize
The size of the text.