pub struct TileLayer {
pub tint: Color32,
pub opacity: f32,
/* private fields */
}Expand description
A layer that manages and renders map tiles on the map view.
Fields
tint: Color32Color tint applied to the tile images when rendering
opacity: f32The opacity of the layer.
Implementations