pub struct SvgElement {
pub pos: GeoPos,
pub text: String,
pub metadata: String,
pub scalable: bool,
pub clickable: bool,
pub draggable: bool,
pub anchor: Pos2,
}Expand description
An SVG element on the map.
Fields
pos: GeoPosThe geographical position (longitude, latitude) of the SVG element.
text: StringThe SVG content string.
metadata: StringArbitrary metadata string, not rendered.
scalable: boolWhether the SVG element should scale with the zoom level. If false, the image size stays the same in screen pixels. If true, the image size scales with the map.
clickable: boolWhether the SVG element is clickable. If true, click events will be emitted for this element. If false, no click events will be emitted.
draggable: boolWhether the SVG element is draggable. If true, the element can be moved on the map by dragging it with the mouse.
anchor: Pos2The anchor point of the SVG element, relative to its size. (0.5, 0.5) is the center (default). (0.0, 0.0) is the top-left. (1.0, 1.0) is the bottom-right.
Implementations
Sourceimpl SvgElement
impl SvgElement
Sourcepub fn new(
pos: GeoPos,
text: impl Into<String>,
metadata: impl Into<String>,
) -> Self
pub fn new( pos: GeoPos, text: impl Into<String>, metadata: impl Into<String>, ) -> Self
Creates a new SVG element.
Sourcepub fn from_xy(
lon: f64,
lat: f64,
text: impl Into<String>,
metadata: impl Into<String>,
) -> Self
pub fn from_xy( lon: f64, lat: f64, text: impl Into<String>, metadata: impl Into<String>, ) -> Self
Creates a new SVG element from x (longitude) and y (latitude) coordinates.
Sourcepub fn with_scalable(self, scalable: bool) -> Self
pub fn with_scalable(self, scalable: bool) -> Self
Sets whether the SVG element is scalable.
Sourcepub fn with_clickable(self, clickable: bool) -> Self
pub fn with_clickable(self, clickable: bool) -> Self
Sets whether the SVG element is clickable.
Sourcepub fn with_draggable(self, draggable: bool) -> Self
pub fn with_draggable(self, draggable: bool) -> Self
Sets whether the SVG element is draggable.
Sourcepub fn with_anchor(self, anchor: Pos2) -> Self
pub fn with_anchor(self, anchor: Pos2) -> Self
Sets the anchor point of the SVG element.