Text layer A layer for placing text on the map.
Structs
- Editing
Text - The state of the text currently being edited or added.
- Text
- A piece of text on the map.
- Text
Layer - Layer implementation that allows placing text on the map.
Enums
- Text
Layer Mode - The mode of the
TextLayer. - Text
Size - The size of the text.